[]Struct android_looper_sys::event::Type

pub struct Type { /* fields omitted */ }

Methods

impl Type

pub const INPUT: Type

ALOOPER_EVENT_INPUT

The file descriptor is available for read operations.

pub const OUTPUT: Type

ALOOPER_EVENT_OUTPUT

The file descriptor is available for write operations.

pub const ERROR: Type

ALOOPER_EVENT_ERROR

The file descriptor has encountered an error condition.

The looper always sends notifications about errors; it is not necessary to specify this event flag in the requested event set.

pub const HANGUP: Type

ALOOPER_EVENT_HANGUP

The file descriptor was hung up. For example, indicates that the remote end of a pipe or socket was closed.

The looper always sends notifications about hangups; it is not necessary to specify this event flag in the requested event set.

pub const INVALID: Type

ALOOPER_EVENT_INVALID

The file descriptor is invalid. For example, the file descriptor was closed prematurely.

The looper always sends notifications about invalid file descriptors; it is not necessary to specify this event flag in the requested event set.

pub fn empty() -> Type

Returns an empty set of flags.

pub fn all() -> Type

Returns the set containing all flags.

pub fn bits(&self) -> isize

Returns the raw value of the flags currently stored.

pub fn from_bits(bits: isize) -> Option<Type>

Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.

pub fn from_bits_truncate(bits: isize) -> Type

Convert from underlying bit representation, dropping any bits that do not correspond to flags.

pub fn is_empty(&self) -> bool

Returns true if no flags are currently stored.

pub fn is_all(&self) -> bool

Returns true if all flags are currently set.

pub fn intersects(&self, other: Type) -> bool

Returns true if there are flags common to both self and other.

pub fn contains(&self, other: Type) -> bool

Returns true all of the flags in other are contained within self.

pub fn insert(&mut self, other: Type)

Inserts the specified flags in-place.

pub fn remove(&mut self, other: Type)

Removes the specified flags in-place.

pub fn toggle(&mut self, other: Type)

Toggles the specified flags in-place.

pub fn set(&mut self, other: Type, value: bool)

Inserts or removes the specified flags depending on the passed value.