Struct android_looper_sys::event::Type
[−]
pub struct Type {
// some fields omitted
}Methods
impl Type
fn empty() -> Type
Returns an empty set of flags.
fn all() -> Type
Returns the set containing all flags.
fn bits(&self) -> isize
Returns the raw value of the flags currently stored.
fn from_bits(bits: isize) -> Option<Type>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
fn from_bits_truncate(bits: isize) -> Type
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
fn is_empty(&self) -> bool
Returns true if no flags are currently stored.
fn is_all(&self) -> bool
Returns true if all flags are currently set.
fn intersects(&self, other: Type) -> bool
Returns true if there are flags common to both self and other.
fn contains(&self, other: Type) -> bool
Returns true all of the flags in other are contained within self.
fn insert(&mut self, other: Type)
Inserts the specified flags in-place.
fn remove(&mut self, other: Type)
Removes the specified flags in-place.
fn toggle(&mut self, other: Type)
Toggles the specified flags in-place.