pub unsafe extern "C" fn ALooper_pollAll(
timeoutMillis: c_int,
outFd: *mut c_int,
outEvents: *mut c_int,
outData: *mut *mut c_void,
) -> c_intExpand description
Like ALooper_pollOnce(), but performs all pending callbacks until all data has been consumed or a file descriptor is available with no callback. This function will never return ALOOPER_POLL_CALLBACK.